- - - - - - -

# Changelog:

#### Version 2.0.1

- Code improvements

#### Version 2.0.0

- Remove `usb-imager-git` from Arch-Linux `AUR` repository
- python min version >= 3.9
- Replace PySide2 with PySide6
- Code improvements and bug fixes

#### Version 1.1

- `usb-imager-git` is now available in the Arch-Linux `AUR` repository
- Writing buffer values changed
- Improve error detection and error messages in case of missing dependencies
- Code improvements and minor bug fixes

#### Version 1.0

- Initial version
